==> zio-aws-securityhub_2.13-5.17.115.1-sources.jar: zio/aws/securityhub/model/RuleGroupSourceStatelessRuleDefinition.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RuleGroupSourceStatelessRuleDefinition(
    actions: Option[Iterable[NonEmptyString]] = None,
    matchAttributes: Option[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition = {
    import RuleGroupSourceStatelessRuleDefinition.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
      .builder()
      .optionallyWith(
        actions.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.actions)
      .optionallyWith(matchAttributes.map(value => value.buildAwsValue()))(
        _.matchAttributes
      )
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly =
    zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition
      .wrap(buildAwsValue())
}
object RuleGroupSourceStatelessRuleDefinition {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition =
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition(
        actions.map(value => value),
        matchAttributes.map(value => value.asEditable)
      )
    def actions: Option[List[NonEmptyString]]
    def matchAttributes: Option[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ]
    def getActions: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("actions", actions)
    def getMatchAttributes: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ] = AwsError.unwrapOptionField("matchAttributes", matchAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ) extends zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly {
    override val actions: Option[List[NonEmptyString]] = scala
      .Option(impl.actions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val matchAttributes: Option[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ] = scala
      .Option(impl.matchAttributes())
      .map(value =>
        zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ): zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-6.20.78.3-sources.jar: zio/aws/securityhub/model/RuleGroupSourceStatelessRuleDefinition.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RuleGroupSourceStatelessRuleDefinition(
    actions: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    matchAttributes: Optional[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition = {
    import RuleGroupSourceStatelessRuleDefinition.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
      .builder()
      .optionallyWith(
        actions.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.actions)
      .optionallyWith(matchAttributes.map(value => value.buildAwsValue()))(
        _.matchAttributes
      )
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly =
    zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition
      .wrap(buildAwsValue())
}
object RuleGroupSourceStatelessRuleDefinition {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition =
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition(
        actions.map(value => value),
        matchAttributes.map(value => value.asEditable)
      )
    def actions: Optional[List[NonEmptyString]]
    def matchAttributes: Optional[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ]
    def getActions: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("actions", actions)
    def getMatchAttributes: ZIO[
      Any,
      AwsError,
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ] = AwsError.unwrapOptionField("matchAttributes", matchAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ) extends zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly {
    override val actions: Optional[List[NonEmptyString]] = zio.aws.core.internal
      .optionalFromNullable(impl.actions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val matchAttributes: Optional[
      zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.matchAttributes())
      .map(value =>
        zio.aws.securityhub.model.RuleGroupSourceStatelessRuleMatchAttributes
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.RuleGroupSourceStatelessRuleDefinition
  ): zio.aws.securityhub.model.RuleGroupSourceStatelessRuleDefinition.ReadOnly =
    new Wrapper(impl)
}
